==> jc-1.4.0.tar.gz: java/security/IntersectingDomainCombiner.h <==
// final class java.security.IntersectingDomainCombiner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 98d3d95120665f97 java_security_IntersectingDomainCombiner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_IntersectingDomainCombiner_H_
#define _JC_java_security_IntersectingDomainCombiner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_IntersectingDomainCombiner$object;

// Typedefs
typedef struct _jc_java_security_IntersectingDomainCombiner$sub_refs	_jc_java_security_IntersectingDomainCombiner$sub_refs;
typedef struct _jc_java_security_IntersectingDomainCombiner$sub_nonrefs	_jc_java_security_IntersectingDomainCombiner$sub_nonrefs;
typedef struct _jc_java_security_IntersectingDomainCombiner$refs	_jc_java_security_IntersectingDomainCombiner$refs;
typedef struct _jc_java_security_IntersectingDomainCombiner$nonrefs	_jc_java_security_IntersectingDomainCombiner$nonrefs;
typedef struct _jc_java_security_IntersectingDomainCombiner$object	_jc_java_security_IntersectingDomainCombiner$object;

typedef struct _jc_java_security_IntersectingDomainCombiner$fields_struct	_jc_java_security_IntersectingDomainCombiner$fields_struct;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vmethods	_jc_java_security_IntersectingDomainCombiner$vmethods;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vtable	_jc_java_security_IntersectingDomainCombiner$vtable;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vtype	_jc_java_security_IntersectingDomainCombiner$vtype;

// Class fields structure
struct _jc_java_security_IntersectingDomainCombiner$fields_struct {
	struct _jc_java_security_IntersectingDomainCombiner$object	*SINGLETON;
};
extern _jc_java_security_IntersectingDomainCombiner$fields_struct _jc_java_security_IntersectingDomainCombiner$class_fields;

// Constructors
extern void _jc_java_security_IntersectingDomainCombiner$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *);

// Virtual methods
extern _jc_object_array *_jc_java_security_IntersectingDomainCombiner$method$combine$f9648237767d4f5a(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_java_security_IntersectingDomainCombiner$method_info$combine$f9648237767d4f5a;

// Static methods
extern void _jc_java_security_IntersectingDomainCombiner$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_security_IntersectingDomainCombiner$vmethods {
	_jc_object_array	*(*combine$f9648237767d4f5a)(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *);
};

// Vtable
struct _jc_java_security_IntersectingDomainCombiner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_IntersectingDomainCombiner$vmethods	java_security_IntersectingDomainCombiner;
};

// Vtype
struct _jc_java_security_IntersectingDomainCombiner$vtype {
	_jc_type			type;
	_jc_java_security_IntersectingDomainCombiner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_IntersectingDomainCombiner$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_IntersectingDomainCombiner$refs {
    _jc_java_security_IntersectingDomainCombiner$sub_refs	java_security_IntersectingDomainCombiner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_IntersectingDomainCombiner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_IntersectingDomainCombiner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_IntersectingDomainCombiner$sub_nonrefs	java_security_IntersectingDomainCombiner;
};

// Object instance structure
struct _jc_java_security_IntersectingDomainCombiner$object {
	_jc_java_security_IntersectingDomainCombiner$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_IntersectingDomainCombiner$vtype	*vtype;
	_jc_java_security_IntersectingDomainCombiner$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_IntersectingDomainCombiner$vtype _jc_java_security_IntersectingDomainCombiner$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_IntersectingDomainCombiner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_IntersectingDomainCombiner$class_object;

#endif	/* _JC_java_security_IntersectingDomainCombiner_H_ */

==> jc-1.4.6.tar.gz: java/security/IntersectingDomainCombiner.h <==
// final class java.security.IntersectingDomainCombiner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 98d3d95120665f97 java_security_IntersectingDomainCombiner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_IntersectingDomainCombiner_H_
#define _JC_java_security_IntersectingDomainCombiner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_IntersectingDomainCombiner$object;

// Typedefs
typedef struct _jc_java_security_IntersectingDomainCombiner$sub_refs	_jc_java_security_IntersectingDomainCombiner$sub_refs;
typedef struct _jc_java_security_IntersectingDomainCombiner$sub_nonrefs	_jc_java_security_IntersectingDomainCombiner$sub_nonrefs;
typedef struct _jc_java_security_IntersectingDomainCombiner$refs	_jc_java_security_IntersectingDomainCombiner$refs;
typedef struct _jc_java_security_IntersectingDomainCombiner$nonrefs	_jc_java_security_IntersectingDomainCombiner$nonrefs;
typedef struct _jc_java_security_IntersectingDomainCombiner$object	_jc_java_security_IntersectingDomainCombiner$object;

typedef struct _jc_java_security_IntersectingDomainCombiner$fields_struct	_jc_java_security_IntersectingDomainCombiner$fields_struct;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vmethods	_jc_java_security_IntersectingDomainCombiner$vmethods;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vtable	_jc_java_security_IntersectingDomainCombiner$vtable;
typedef const struct _jc_java_security_IntersectingDomainCombiner$vtype	_jc_java_security_IntersectingDomainCombiner$vtype;

// Class fields structure
struct _jc_java_security_IntersectingDomainCombiner$fields_struct {
	struct _jc_java_security_IntersectingDomainCombiner$object	*SINGLETON;
};
extern _jc_java_security_IntersectingDomainCombiner$fields_struct _jc_java_security_IntersectingDomainCombiner$class_fields;

// Constructors
extern void _jc_java_security_IntersectingDomainCombiner$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_java_security_IntersectingDomainCombiner$method$combine$f9648237767d4f5a(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_IntersectingDomainCombiner$method_info$combine$f9648237767d4f5a;

// Static methods
extern void _jc_java_security_IntersectingDomainCombiner$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_security_IntersectingDomainCombiner$vmethods {
	_jc_object_array	*(*combine$f9648237767d4f5a)(_jc_env *, struct _jc_java_security_IntersectingDomainCombiner$object *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_IntersectingDomainCombiner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_IntersectingDomainCombiner$vmethods	java_security_IntersectingDomainCombiner;
};

// Vtype
struct _jc_java_security_IntersectingDomainCombiner$vtype {
	_jc_type			type;
	_jc_java_security_IntersectingDomainCombiner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_IntersectingDomainCombiner$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_IntersectingDomainCombiner$refs {
    _jc_java_security_IntersectingDomainCombiner$sub_refs	java_security_IntersectingDomainCombiner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_IntersectingDomainCombiner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_IntersectingDomainCombiner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_IntersectingDomainCombiner$sub_nonrefs	java_security_IntersectingDomainCombiner;
};

// Object instance structure
struct _jc_java_security_IntersectingDomainCombiner$object {
	_jc_java_security_IntersectingDomainCombiner$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_IntersectingDomainCombiner$vtype	*vtype;
	_jc_java_security_IntersectingDomainCombiner$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_IntersectingDomainCombiner$vtype _jc_java_security_IntersectingDomainCombiner$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_IntersectingDomainCombiner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_IntersectingDomainCombiner$class_object;

#endif	/* _JC_java_security_IntersectingDomainCombiner_H_ */
